==> haskell-th-expand-syns-0.4.4.0-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-th-expand-syns.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-expand-syns
version: 0.4.4.0
id: th-expand-syns-0.4.4.0-ACeG5Fd2nA9J5jHwfmyY63
key: th-expand-syns-0.4.4.0-ACeG5Fd2nA9J5jHwfmyY63
license: BSD-3-Clause
maintainer: haskell.5wlh@gishpuppy.com
author: Daniel Schüssler
homepage: https://github.com/DanielSchuessler/th-expand-syns
synopsis: Expands type synonyms in Template Haskell ASTs
description:
    Expands type synonyms in Template Haskell ASTs.
category: Template Haskell
abi: 14f857082ef86dd3036f00cb10ca3e26
exposed: True
exposed-modules:
    Language.Haskell.TH.ExpandSyns
hidden-modules: Language.Haskell.TH.ExpandSyns.SemigroupCompat
import-dirs: /usr/lib/ghc-8.6.5/site-local/th-expand-syns-0.4.4.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/th-expand-syns-0.4.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/th-expand-syns-0.4.4.0
hs-libraries: HSth-expand-syns-0.4.4.0-ACeG5Fd2nA9J5jHwfmyY63
depends:
    base-4.12.0.0 containers-0.6.0.1 syb-0.7.1-1gO4OjQOULM8usUjWwwEyW
    template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-th-expand-syns/html/th-expand-syns.haddock
haddock-html: /usr/share/doc/haskell-th-expand-syns/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-expand-syns-0.4.5.0-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-th-expand-syns.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-expand-syns
version: 0.4.5.0
id: th-expand-syns-0.4.5.0-9MmbxLXOBDyEihN0YbdbeC
key: th-expand-syns-0.4.5.0-9MmbxLXOBDyEihN0YbdbeC
license: BSD-3-Clause
maintainer: haskell.5wlh@gishpuppy.com
author: Daniel Schüssler
homepage: https://github.com/DanielSchuessler/th-expand-syns
synopsis: Expands type synonyms in Template Haskell ASTs
description:
    Expands type synonyms in Template Haskell ASTs.
category: Template Haskell
abi: debd4bc940bcb1dbc5218644732aeaf7
exposed: True
exposed-modules:
    Language.Haskell.TH.ExpandSyns
hidden-modules: Language.Haskell.TH.ExpandSyns.SemigroupCompat
import-dirs: /usr/lib/ghc-8.6.5/site-local/th-expand-syns-0.4.5.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/th-expand-syns-0.4.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/th-expand-syns-0.4.5.0
hs-libraries: HSth-expand-syns-0.4.5.0-9MmbxLXOBDyEihN0YbdbeC
depends:
    base-4.12.0.0 containers-0.6.0.1 syb-0.7.1-1gO4OjQOULM8usUjWwwEyW
    template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-th-expand-syns/html/th-expand-syns.haddock
haddock-html: /usr/share/doc/haskell-th-expand-syns/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
